﻿# This is a Database script to create the Small Business System (SBS)
# database table from scratch
#
# Created by  : Felix Kang - I-CAT Computing
# Created On  : 28 JUL 2005
# Requirement : mySQL v5.0.26 and above
# Note        : - This script has to be run as root or other user who has permission to create database and assign rights
#
#------------------------------------------------------------------------------------
# History
# - 28 JUL 2005: database script creation
# - 15 DEC 2005: Adjustment on scripts to make it more comply to relational database structure
#------------------------------------------------------------------------------------

# Create database - add customer name if necessary
CREATE DATABASE SBS;

# Set the newly created database as our current database
USE SBS;

# Create the Customer table for companies
CREATE TABLE CUSTOMER_COMPANY (
  COMPANY_ID       VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Company ID, a unique identification for each company',
  COMPANY_NAME     VARCHAR(50)   NOT NULL COMMENT 'Company Name',
  ADDRESS_1        VARCHAR(200)  COMMENT '1st Line of Address',
  ADDRESS_2        VARCHAR(200)  COMMENT '2nd Line of Address',
  CITY             VARCHAR(50)   COMMENT 'City',
  SUBURB           VARCHAR(100)  COMMENT 'Suburb',
  STATE            VARCHAR(100)  COMMENT 'State',
  POSTCODE         VARCHAR(10)   COMMENT 'Postcode',
  COUNTRY          VARCHAR(50)   COMMENT 'Country',
  PHONE_NO1        VARCHAR(20)   COMMENT 'Phone Number 1',
  PHONE_NO2        VARCHAR(20)   COMMENT 'Phone Number 2',
  FAX_NO           VARCHAR(20)   COMMENT 'Fax Number',
  E_MAIL           VARCHAR(200)  COMMENT 'E-mail address',
  WEBPAGE_ADD      VARCHAR(300)  COMMENT 'Company webpage',
  CREATION_DATE    DATETIME      COMMENT 'The date the customer join',
  JOIN_LOC         VARCHAR(50)   COMMENT 'The office where they get registered',
  SALES_VALUE      DECIMAL(18,2) COMMENT 'The sum of sales generated by this client',
  ABN_ACN_NUMBER   VARCHAR(20)   COMMENT 'ABN or ACN Number of the company',
  PAYMENT_TERMS    SMALLINT      COMMENT 'Payment terms in number of days',
  REMARKS          TEXT          COMMENT 'Remarks',
  GROUPING         VARCHAR(100)  COMMENT 'GROUP TAG',
  COMPANY_TYPE     VARCHAR(100)  COMMENT 'Type of the customer company, whether a customer or supplier',
  RECORD_STATUS    VARCHAR(20)   COMMENT 'Display the record status, whether it is active or inactive',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

# Create the Customer table for companies
CREATE TABLE COMPANY_OPPORTUNITY (
  OPPORTUNITY_ID   VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Opportunity ID, a unique identification for each opportunity',
  COMPANY_ID       VARCHAR(50)   NOT NULL COMMENT 'Company ID',
  TOPIC            TEXT          COMMENT 'Topic of the opportunity',
  SUMMARY          TEXT          COMMENT 'Summary of the opportunity',
  CONTACT_NAME     VARCHAR(50)   COMMENT 'The contact name related to the opportunity',
  FOLLOW_UP_DATE   DATETIME      COMMENT 'A date to follow up the opportunity',
  REMIND_USER      VARCHAR(10)    COMMENT 'A flag whether user needs to be reminded to follow up this opportunity',
  IMPORTANCE       VARCHAR(20)   COMMENT 'Level of Importance of this topic',
  CREATED_BY       VARCHAR(20)   COMMENT 'User id/username',
  CREATION_DATE    DATETIME      COMMENT 'The date the record was created',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified'
);

# Create the Contacts table
CREATE TABLE COMPANY_CONTACTS (
  CONTACT_ID       VARCHAR(50)   NOT NULL COMMENT 'Contact ID, a unique identification for each contact',
  COMPANY_ID       VARCHAR(50)   NOT NULL COMMENT 'Company ID, a unique identification for each company',
  TITLE            VARCHAR(20)   COMMENT 'Title,(i.e:Mr,Ms,Mrs)',
  FIRST_NAME       VARCHAR(50)   COMMENT 'First Name',
  MIDDLE_NAME      VARCHAR(50)   COMMENT 'Middle Name',
  LAST_NAME        VARCHAR(50)   COMMENT 'Last Name',
  POSITION         VARCHAR(100)  COMMENT 'Contact position in the company',
  ADDRESS_1        VARCHAR(200)  COMMENT '1st Line of Address',
  ADDRESS_2        VARCHAR(200)  COMMENT '2nd Line of Address',
  CITY             VARCHAR(50)   COMMENT 'City',
  SUBURB           VARCHAR(100)  COMMENT 'Suburb',
  STATE            VARCHAR(100)  COMMENT 'State',
  POSTCODE         VARCHAR(10)   COMMENT 'Postcode',
  COUNTRY          VARCHAR(50)   COMMENT 'Country',
  HOME_NO          VARCHAR(20)   COMMENT 'Home Number',
  MOBILE_NO        VARCHAR(20)   COMMENT 'Mobile Number',
  WORK_NO          VARCHAR(20)   COMMENT 'Work Number',
  FAX_NO           VARCHAR(20)   COMMENT 'Fax Number',
  E_MAIL           VARCHAR(200)  COMMENT 'E-mail address',
  CREATION_DATE    DATETIME      COMMENT 'The date the record for this contact gets created',
  SEX              VARCHAR(10)   COMMENT 'Male/Female',
  DOB              DATE          COMMENT 'Date of Birth',
  NAMECARD_PATH    VARCHAR(300)  COMMENT 'File path pointing to the image of namecard',
  GROUPING         VARCHAR(100)  COMMENT 'GROUP TAG',
  REMARKS          TEXT          COMMENT 'Remarks',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record',

  PRIMARY KEY(CONTACT_ID,COMPANY_ID),
  FOREIGN KEY(COMPANY_ID) REFERENCES CUSTOMER_COMPANY(COMPANY_ID)
);

# Create the Customer table for a customer
CREATE TABLE CUSTOMER_INDIVIDUAL (
  CUSTOMER_ID      VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Customer ID, a unique identification for each customer',
  TITLE            VARCHAR(20)   COMMENT 'Title,(i.e:Mr,Ms,Mrs)',
  FIRST_NAME       VARCHAR(50)   NOT NULL COMMENT 'First Name',
  MIDDLE_NAME      VARCHAR(50)   COMMENT 'Middle Name',
  LAST_NAME        VARCHAR(50)   COMMENT 'Last Name',
  ADDRESS_1        VARCHAR(200)  COMMENT '1st Line of Address',
  ADDRESS_2        VARCHAR(200)  COMMENT '2nd Line of Address',
  CITY             VARCHAR(50)   COMMENT 'City',
  SUBURB           VARCHAR(100)  COMMENT 'Suburb',
  STATE            VARCHAR(100)  COMMENT 'State',
  POSTCODE         VARCHAR(10)   COMMENT 'Postcode',
  COUNTRY          VARCHAR(50)   COMMENT 'Country',
  HOME_NO          VARCHAR(20)   COMMENT 'Home Number',
  MOBILE_NO        VARCHAR(20)   COMMENT 'Mobile Number',
  WORK_NO          VARCHAR(20)   COMMENT 'Work Number',
  FAX_NO           VARCHAR(20)   COMMENT 'Fax Number',
  E_MAIL           VARCHAR(200)  COMMENT 'E-mail address',
  CREATION_DATE    DATETIME      COMMENT 'The date the record for this customer join',
  JOIN_LOC         VARCHAR(50)   COMMENT 'The office where they get registered',
  SALES_VALUE      DECIMAL(18,2) COMMENT 'The sum of sales generated by this client',
  REMARKS          TEXT          COMMENT 'Remarks',
  SEX              VARCHAR(10)   COMMENT 'Male/Female',
  DOB              DATE          COMMENT 'Date of Birth',
  GROUPING         VARCHAR(100)  COMMENT 'GROUP TAG',
  CUSTOMER_TYPE    VARCHAR(100)  COMMENT 'Type of the customer company, whether a customer or supplier',
  RECORD_STATUS    VARCHAR(20)   COMMENT 'Display the record status, whether it is active or inactive',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

# Create the Settings table
CREATE TABLE PROGRAM_SETTINGS (
  SETTINGS_NAME     VARCHAR(50)  COMMENT 'The name of the settings',
  SETTINGS_VALUE    VARCHAR(250) COMMENT 'Value',

  PRIMARY KEY(SETTINGS_NAME,SETTINGS_VALUE)
);

#Create Table to store the name of countries, states, suburbs
CREATE TABLE COUNTRIES (
  COUNTRY_NAME     VARCHAR(100)  COMMENT 'The name of the country',
  STATE_NAME       VARCHAR(100)  COMMENT 'The name of the state - within that country',
  CITY_NAME        VARCHAR(100)  COMMENT 'The name of the city - within that state',
  SUBURB_NAME      VARCHAR(100)  COMMENT 'The name of the suburb - within that state',

  PRIMARY KEY(COUNTRY_NAME,STATE_NAME,CITY_NAME,SUBURB_NAME)
);

#Create Table to store the lookup values, mainly when using combo boxes
CREATE TABLE LOOKUP_VALUES (
  MODULE_NAME      VARCHAR(100)   COMMENT 'The name of the module that uses this lookup values',
  LOOKUP_NAME      VARCHAR(100)   COMMENT 'Lookup Name',
  LOOKUP_VALUE     VARCHAR(250)   COMMENT 'Lookup Value',

  PRIMARY KEY(MODULE_NAME,LOOKUP_NAME,LOOKUP_VALUE)
);
CREATE TABLE LINKED_LOOKUP_VALUES (
  MODULE_NAME      VARCHAR(100)   COMMENT 'The name of the module that uses this linked lookup values',
  LOOKUP_NAME_01   VARCHAR(100)   COMMENT 'Lookup Name 01',
  LOOKUP_VALUE_01  VARCHAR(250)   COMMENT 'Lookup Value 01',
  LOOKUP_NAME_02   VARCHAR(100)   COMMENT 'Lookup Name 02',
  LOOKUP_VALUE_02  VARCHAR(250)   COMMENT 'Lookup Value 02',
  LOOKUP_NAME_03   VARCHAR(100)   COMMENT 'Lookup Name 03',
  LOOKUP_VALUE_03  VARCHAR(250)   COMMENT 'Lookup Value 03',

  PRIMARY KEY(MODULE_NAME,LOOKUP_NAME_01,LOOKUP_NAME_02,LOOKUP_NAME_03)
);

#Create Table to store the user details
CREATE TABLE USERS (
  USER_ID          VARCHAR(20)   NOT NULL PRIMARY KEY COMMENT 'User id/username',
  USER_PASSWORD    VARCHAR(300)  NOT NULL COMMENT 'User password, encrypted',
  ADMIN_RIGHTS     VARCHAR(5)    COMMENT 'YES = User has unlimited access (admin), NO = Need individual access allocation',
  USER_RIGHTS      TEXT          COMMENT 'User rights in bracket format, for example, [RUN_CRM_COMPANY]',
  ENABLED          VARCHAR(5)    COMMENT 'YES = User can be used in the system, NO = user cannot get into the system',
  REMARKS          TEXT          COMMENT 'Remarks',
  DATE_CREATED     DATETIME      COMMENT 'The date when this user is created',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

#Create Table to store the history details
CREATE TABLE HISTORY (
  HISTORY_ID       VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'History ID',
  HISTORY_TEXT     TEXT          COMMENT 'The actual text',
  CREATED_BY       VARCHAR(20)   COMMENT 'User id/username',
  CREATION_DATE    DATETIME      COMMENT 'The date the record was created',
  TABLE_OWNER      VARCHAR(50)   COMMENT 'Parent Table name who owns the entries',
  KEY_FIELDNAME_1  VARCHAR(50)   COMMENT 'The name of the first key field',
  KEY_FIELDVALUE_1 VARCHAR(50)   COMMENT 'The value of the first key field',
  KEY_FIELDNAME_2  VARCHAR(50)   COMMENT 'The name of the first key field',
  KEY_FIELDVALUE_2 VARCHAR(50)   COMMENT 'The value of the first key field',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

#Create Table to store the document details
CREATE TABLE DOCUMENTS (
  DOCUMENT_ID      VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Document ID',
  DOCUMENT_TYPE    VARCHAR(100)  COMMENT 'Document type, invoice, faxes, etc',
  DOCUMENT_NAME    VARCHAR(100)  COMMENT 'Document Name',
  DOCUMENT_PATH    VARCHAR(500)  COMMENT 'The complete path to the document including path + filename',
  REMARKS          TEXT          COMMENT 'A remark for this document',
  TABLE_OWNER      VARCHAR(50)   COMMENT 'Parent Table name who owns the entries',
  KEY_FIELDNAME_1  VARCHAR(50)   COMMENT 'The name of the first key field',
  KEY_FIELDVALUE_1 VARCHAR(50)   COMMENT 'The value of the first key field',
  KEY_FIELDNAME_2  VARCHAR(50)   COMMENT 'The name of the first key field',
  KEY_FIELDVALUE_2 VARCHAR(50)   COMMENT 'The value of the first key field',
  CREATED_BY       VARCHAR(20)   COMMENT 'User id/username',
  CREATION_DATE    DATETIME      COMMENT 'The date the record was created',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

#Create Table to store the extra information from company's contact
CREATE TABLE EXTRA_INFO (
  EXTRA_INFO_ID    VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Extra Info Unique DB ID',
  FIELD_NAME       VARCHAR(100)  COMMENT 'Field Name, invoice, faxes, etc',
  FIELD_TEXT       TEXT          COMMENT 'The actual text',
  TABLE_OWNER      VARCHAR(50)   COMMENT 'Parent Table name who owns the entries',
  KEY_FIELDNAME_1  VARCHAR(50)   COMMENT 'The name of the first key field',
  KEY_FIELDVALUE_1 VARCHAR(50)   COMMENT 'The value of the first key field',
  KEY_FIELDNAME_2  VARCHAR(50)   COMMENT 'The name of the first key field',
  KEY_FIELDVALUE_2 VARCHAR(50)   COMMENT 'The value of the first key field',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

#Create Table to store the stock/item/inventory information
CREATE TABLE PRODUCT (
  PRODUCT_ID       VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Product/Item Unique DB ID',
  PRODUCT_CODE     VARCHAR(50)   COMMENT 'Internal/vendor Product Code',
  PRODUCT_NAME     VARCHAR(50)   COMMENT 'Product/item name',
  PRODUCT_DESC     VARCHAR(100)  COMMENT 'Product/item description',
  PRODUCT_TYPE     VARCHAR(10)   COMMENT 'A product can be goods or services',
  PRODUCT_GROUP    VARCHAR(100)  COMMENT 'A grouping field for this product',
  QUANTITY         DECIMAL(10,2) COMMENT 'Current quantity of the product',
  QUANTITY_UNIT    VARCHAR(10)   COMMENT 'Quantity unit used for this item',
  REORDER_QTY      DECIMAL(10,2) COMMENT 'Indicator at which point a reminder needs to be sent to re-order stock',
  SUPPLIER_COMP    VARCHAR(50)   COMMENT 'Company Name that supply this item/product',
  COST_PRICE       DECIMAL(10,2) COMMENT 'The cost price of this product (Ex-GST)',
  RRP              DECIMAL(10,2) COMMENT 'The recommended retail price for this item (Ex-GST)',
  SELLING_PRICE    DECIMAL(10,2) COMMENT 'Current selling price (Ex-GST)',
  HOURLY_RATE      DECIMAL(10,2) COMMENT 'Hourly rate of services (only applicable if the type is services (Ex-GST)',
  IMAGE_PATH       VARCHAR(300)  COMMENT 'The complete image path to the actual product',
  PROD_LIT_PATH    VARCHAR(300)  COMMENT 'Path for a product literature',
  REMARKS          TEXT          COMMENT 'Remarks for this item/stock',
  RECORD_STATUS    VARCHAR(20)   COMMENT 'Display the record status, whether it is active or inactive',
  BARCODE          VARCHAR(100)  COMMENT 'Barcode value attached to the product',
  AMT_SOLD_TODATE  INT           COMMENT 'Record how many of this product has been sold to date',
  CREATION_DATE    DATETIME      COMMENT 'The date the record was created',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'
);

#Create Table to store the quote information
CREATE TABLE QUOTE (
  QUOTE_ID         VARCHAR(50)   NOT NULL COMMENT 'Quote ID',
  QUOTE_VERSION    SMALLINT      NOT NULL COMMENT 'Versions of the quote',
  QUOTE_STATUS     VARCHAR(3)    COMMENT 'Status of the quote, obsolete or current',
  INVOICE_ID       VARCHAR(20)   COMMENT 'Invoice ID that derive its content from this quote',
  QUOTE_DATE       DATETIME      COMMENT 'Date printed on the quote',
  CUSTOMER_NAME    VARCHAR(50)   COMMENT 'The name of the recipient',
  CONTACT_NAME     VARCHAR(50)   COMMENT 'The name of the contacts, mainly for companies',
  ABN_ACN_NUMBER   VARCHAR(20)   COMMENT 'ABN or ACN Number of the company',
  CUSTOMER_ADDRESS VARCHAR(100)  COMMENT 'Address of the recipient',
  CONTACT_DETAILS  VARCHAR(100)  COMMENT 'Contact details of the company',
  REPORT_TEMPLATE  VARCHAR(50)   COMMENT 'The name of the report template to generate a printed quote',
  CUST_TYPE        VARCHAR(50)   COMMENT 'Customer Type, Customer/Company',
  REMARKS          TEXT          COMMENT 'Remarks for this quote',
  CREATION_DATE    DATETIME      COMMENT 'The date the record was created',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record',

  PRIMARY KEY(QUOTE_ID,QUOTE_VERSION)
);

#Create Table to store the quotation details
CREATE TABLE QUOTE_DETAILS (
  QUOTE_ID         VARCHAR(50)   NOT NULL COMMENT 'Quote ID',
  QUOTE_VERSION    SMALLINT      NOT NULL COMMENT 'Versions of the quote',
  QUOTE_LINE_NO    SMALLINT      NOT NULL COMMENT 'Line no of the quote item, will be used to construct the quote',
  PRODUCT_ID       VARCHAR(20)   COMMENT 'Product/Item Unique DB ID',
  PRODUCT_CODE     VARCHAR(50)   COMMENT 'Internal Product Code',
  QUOTE_ITEM_DESC  VARCHAR(100)  COMMENT 'Quote item description',
  QUANTITY         DECIMAL(8,2)  COMMENT 'Quantity of the product',
  PRICE_EX_GST     DECIMAL(10,2) COMMENT 'The price of this product (Ex-GST)',
  GST              DECIMAL(10,2) COMMENT 'The value of GST for this item',
  PRICE_INC_GST    DECIMAL(10,2) COMMENT 'The price of this product (Inc-GST)',

  PRIMARY KEY(QUOTE_ID,QUOTE_VERSION,QUOTE_LINE_NO)
);

#Create Table to store the invoice information
CREATE TABLE INVOICE (
  INVOICE_ID         VARCHAR(50)   NOT NULL COMMENT 'INVOICE ID',
  INVOICE_VERSION    SMALLINT      NOT NULL COMMENT 'Versions of the INVOICE',
  INVOICE_STATUS     VARCHAR(3)    COMMENT 'Status of the INVOICE, obsolete or current',
  INVOICE_DATE       DATETIME      COMMENT 'Date printed on the INVOICE',
  INVOICE_DUE_DATE   DATETIME      COMMENT 'Due Date for this INVOICE',
  INVOICE_PAID       VARCHAR(20)   COMMENT 'A mark to say whether this invoice has been paid or not',
  CUSTOMER_NAME      VARCHAR(50)   COMMENT 'The name of the recipient',
  CONTACT_NAME       VARCHAR(50)   COMMENT 'The name of the contacts, mainly for companies',
  ABN_ACN_NUMBER     VARCHAR(20)   COMMENT 'ABN or ACN Number of the company',
  CUSTOMER_ADDRESS   VARCHAR(100)  COMMENT 'Address of the recipient',
  CONTACT_DETAILS    VARCHAR(100)  COMMENT 'Contact details of the company',
  REPORT_TEMPLATE    VARCHAR(50)   COMMENT 'The name of the report template to generate a printed INVOICE',
  CUST_TYPE          VARCHAR(50)   COMMENT 'Customer Type, Customer/Company',
  REMARKS            TEXT          COMMENT 'Remarks for this item/stock',
  CREATION_DATE      DATETIME      COMMENT 'The date the record was created',
  MODIFIED_TIME      DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY        VARCHAR(100)  COMMENT 'Username of the person who modified this record',

  PRIMARY KEY(INVOICE_ID,INVOICE_VERSION)
);

#Create Table to store the invoice details
CREATE TABLE INVOICE_DETAILS (
  INVOICE_ID         VARCHAR(50)   NOT NULL COMMENT 'Invoice ID',
  INVOICE_VERSION    SMALLINT      NOT NULL COMMENT 'Versions of the invoice',
  INVOICE_LINE_NO    SMALLINT      NOT NULL COMMENT 'Line no of the INVOICE item, will be used to construct the INVOICE',
  PRODUCT_ID         VARCHAR(20)   COMMENT 'Product/Item Unique DB ID',
  PRODUCT_CODE       VARCHAR(50)   COMMENT 'Internal Product Code',
  INVOICE_ITEM_DESC  VARCHAR(100)  COMMENT 'Invoice item description',
  QUANTITY           DECIMAL(8,2)  COMMENT 'Quantity of the product',
  PRICE_EX_GST       DECIMAL(10,2) COMMENT 'The price of this product (Ex-GST)',
  GST                DECIMAL(10,2) COMMENT 'The value of GST for this item',
  PRICE_INC_GST      DECIMAL(10,2) COMMENT 'The price of this product (Inc-GST)',

  PRIMARY KEY(INVOICE_ID,INVOICE_VERSION,INVOICE_LINE_NO)
);

#Create Table to store the reports
CREATE TABLE REPORT (
  REPORT_ID         VARCHAR(50)   NOT NULL COMMENT 'Report ID',
  REPORT_DESC       VARCHAR(100)  COMMENT 'Report Description',
  LINK_MODULE_NAME  VARCHAR(100)  COMMENT 'Name of module that this report linked to',
  REPORT_PATH       VARCHAR(300)  COMMENT 'Actual path to the report',
  MODIFIED_TIME     DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY       VARCHAR(100)  COMMENT 'Username of the person who modified this record',

  PRIMARY KEY(REPORT_ID)
);

#Create Table to store the personnel data
CREATE TABLE PERSONNEL (
  PERSONNEL_ID     VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Personnel ID',
  TITLE            VARCHAR(20)   COMMENT 'Title,(i.e:Mr,Ms,Mrs)',
  FIRST_NAME       VARCHAR(50)   COMMENT 'First Name',
  MIDDLE_NAME      VARCHAR(50)   COMMENT 'Middle Name',
  LAST_NAME        VARCHAR(50)   COMMENT 'Last Name',
  JOB_TITLE        VARCHAR(100)  COMMENT 'Personnel position in the company',
  DEPARTMENT       VARCHAR(100)  COMMENT 'Department assigned to this staff',
  HOME_ADDRESS_1   VARCHAR(200)  COMMENT '1st Line of Home Address',
  HOME_ADDRESS_2   VARCHAR(200)  COMMENT '2nd Line of Home Address',
  CITY             VARCHAR(50)   COMMENT 'City',
  SUBURB           VARCHAR(100)  COMMENT 'Suburb',
  STATE            VARCHAR(100)  COMMENT 'State',
  POSTCODE         VARCHAR(10)   COMMENT 'Postcode',
  COUNTRY          VARCHAR(50)   COMMENT 'Country',
  HOME_NO          VARCHAR(20)   COMMENT 'Home Number',
  MOBILE_NO        VARCHAR(20)   COMMENT 'Mobile Number',
  FAX_NO           VARCHAR(20)   COMMENT 'Fax Number',
  E_MAIL           VARCHAR(200)  COMMENT 'E-mail address',
  CREATION_DATE    DATETIME      COMMENT 'The date the record for this contact gets created',
  WORK_STATUS      VARCHAR(50)   COMMENT 'Whether it is full-time, part-time, or casual',
  SEX              VARCHAR(10)   COMMENT 'Male/Female',
  DOB              DATE          COMMENT 'Date of Birth',
  START_DATE       DATE          COMMENT 'Starting Date',
  GROUPING         VARCHAR(100)  COMMENT 'GROUP TAG',
  REMARKS          TEXT          COMMENT 'Remarks',
  USERNAME         VARCHAR(50)   COMMENT 'Assigned username',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record'

);

#Create Table to store the personnel's next-of-kin
CREATE TABLE PERSONNEL_NEXTOF_KIN (
  NEXTOFKIN_ID     VARCHAR(50)   NOT NULL COMMENT 'Next of Kin ID',
  PERSONNEL_ID     VARCHAR(50)   NOT NULL COMMENT 'Personnel ID',
  RELATIONSHIP     VARCHAR(50)   COMMENT 'The relationship with staff member',
  TITLE            VARCHAR(20)   COMMENT 'Title,(i.e:Mr,Ms,Mrs)',
  FIRST_NAME       VARCHAR(50)   COMMENT 'First Name',
  MIDDLE_NAME      VARCHAR(50)   COMMENT 'Middle Name',
  LAST_NAME        VARCHAR(50)   COMMENT 'Last Name',
  HOME_ADDRESS_1   VARCHAR(200)  COMMENT '1st Line of Home Address',
  HOME_ADDRESS_2   VARCHAR(200)  COMMENT '2nd Line of Home Address',
  CITY             VARCHAR(50)   COMMENT 'City',
  SUBURB           VARCHAR(100)  COMMENT 'Suburb',
  STATE            VARCHAR(100)  COMMENT 'State',
  POSTCODE         VARCHAR(10)   COMMENT 'Postcode',
  COUNTRY          VARCHAR(50)   COMMENT 'Country',
  HOME_NO          VARCHAR(20)   COMMENT 'Home Number',
  MOBILE_NO        VARCHAR(20)   COMMENT 'Mobile Number',
  WORK_NO          VARCHAR(20)   COMMENT 'Work Number',
  FAX_NO           VARCHAR(20)   COMMENT 'Fax Number',
  E_MAIL           VARCHAR(200)  COMMENT 'E-mail address',
  CREATION_DATE    DATETIME      COMMENT 'The date the record for this contact gets created',
  REMARKS          TEXT          COMMENT 'Remarks',
  MODIFIED_TIME    DATETIME      COMMENT 'Last date and time this record was modified',
  MODIFIED_BY      VARCHAR(100)  COMMENT 'Username of the person who modified this record',

  PRIMARY KEY(NEXTOFKIN_ID,PERSONNEL_ID)
);

#Create Table to store the personnel's next-of-kin
CREATE TABLE PERSONNEL_QUALIFICATION (
  PQ_ID            VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'PQ (Personal Qualification ID) It is just a unique record ID',
  PERSONNEL_ID     VARCHAR(50)   NOT NULL COMMENT 'Personnel ID',
  QUALF_ID         VARCHAR(50)   NOT NULL COMMENT 'Qualification ID',
  QUALF_TYPE       VARCHAR(50)   COMMENT 'Qualification type',
  QUALF_DESC       VARCHAR(200)  COMMENT 'The description of the qualification',
  DATE_TAKEN       DATETIME      COMMENT 'The date the staff taken the qualification',
  DATE_GRANTED     DATETIME      COMMENT 'The date the staff granted the qualification',
  VENDOR           VARCHAR(50)   COMMENT 'The vendor/company name whose providing this qualification',
  RENEWABLE        VARCHAR(10)   COMMENT 'Wheteher this qualification needs to be renewed',
  RENEW_DATE       DATETIME      COMMENT 'The date the qualifcation should be renewed'

);

#Create Table to store the personnel's next-of-kin
CREATE TABLE QUALIFICATION (
  QUALF_ID         VARCHAR(50)   NOT NULL COMMENT 'Qualification ID',
  QUALF_TYPE       VARCHAR(50)   COMMENT 'Qualification type',
  QUALF_DESC       VARCHAR(200)  COMMENT 'The description of the qualification',
  VENDOR_NAME      VARCHAR(50)   COMMENT 'The vendor/company name whose providing this qualification',
  RENEWABLE        VARCHAR(10)   COMMENT 'Wheteher this qualification needs to be renewed',
  RENEW_PERIOD     SMALLINT      COMMENT 'The number of days this qualification must be renewed'

);

#Create Table to store the personnel's next-of-kin
CREATE TABLE PERSONNEL_ABSENCES (
  PERSONNEL_ABS_ID VARCHAR(50)   NOT NULL PRIMARY KEY COMMENT 'Unique ID for Personnel Absences table',
  PERSONNEL_ID     VARCHAR(50)   NOT NULL COMMENT 'Personnel ID',
  ABSENCE_TYPE     VARCHAR(100)  COMMENT 'The description of the Absence Type',
  ABSENCE_QUOTA    DECIMAL(10,4) COMMENT 'The amount allocated as a quota based on employment date',
  ABSENCE_HOURS    DECIMAL(10,4) COMMENT 'The amount hours taken for this absence',
  DATE_ABS_TAKEN   DATETIME      COMMENT 'The date the leave/absence was taken',
  LAST_ABS_UPDATE  DATETIME      COMMENT 'Last update of absences for this staff',
  REASON           TEXT          COMMENT 'Reason for the absence',
  RECORD_FLAG      VARCHAR(50)   COMMENT 'Internal flag for various purposes, not to be shown to users'

);

#Create Table to store the system events
CREATE TABLE SYSTEM_EVENTS (
  EVENT_ID         VARCHAR(50)    NOT NULL COMMENT 'Assigned Event ID',
  KEY_RECORD_1     VARCHAR(50)    NOT NULL COMMENT 'Key record ID 1, will be used to retrieve the record',
  KEY_RECORD_2     VARCHAR(50)    NOT NULL COMMENT 'Key record ID 2, will be used to retrieve the record',
  KEY_RECORD_3     VARCHAR(50)    NOT NULL COMMENT 'Key record ID 3, will be used to retrieve the record',
  MODULE_ID        VARCHAR(50)    COMMENT 'Module ID',
  DESCRIPTION      TEXT           COMMENT 'A descriptive text of the event',
  DATE_TIME        DATETIME       COMMENT 'Date and time of when the event happened',
  EVENT_FLAG       VARCHAR(50)    COMMENT 'Flags for system use',
  USERNAME         VARCHAR(50)    COMMENT 'Assigned username',
  NEXT_REMINDER    DATETIME       COMMENT 'Date and time for the next reminder',
  DISMISS          VARCHAR(10)    COMMENT 'TRUE means do not mention this record again in reminder',

PRIMARY KEY(EVENT_ID,KEY_RECORD_1,KEY_RECORD_2,KEY_RECORD_3)

);

#Create indexes on some table to make search faster
CREATE INDEX IDX_CUSTOMER_COMPANY_COMPANY_NAME ON CUSTOMER_COMPANY(COMPANY_NAME);
CREATE INDEX IDX_COMPANY_CONTACTS_FIRST_NAME ON COMPANY_CONTACTS (TITLE,FIRST_NAME,MIDDLE_NAME,LAST_NAME);
CREATE INDEX IDX_CUSTOMER_INDIVIDUAL_FIRST_NAME ON CUSTOMER_INDIVIDUAL (TITLE,FIRST_NAME,MIDDLE_NAME,LAST_NAME);


# Create access to default username and password to be used by SBS System.
# in mySQL, access should be created later when everything has been created
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, REFERENCES, DROP
  ON SBS.*
  TO 'SBSYSTEM'@'%'
  IDENTIFIED BY 'SBSystem2005';